import React from 'react';
import Taro from '@tarojs/taro';
import { Tabbar, TabbarItem } from '@antmjs/vantui'
import { View, Slot } from '@tarojs/components';
import NavBar from '../navbar';
import './style.less';

let active = 0;

export default (props) => {
  const { className = '', style = {}, custom = true, title = "myApp", showHome = false } = props;

  const onTabChange = (e) => {
    const index = e.detail;
    active = index;
    const tabPage = [
      '/pages/index/index',
      '/pages/mine/index',
    ]

    const url = tabPage[index];
    Taro.reLaunch({ url });
  }

  const innerStyle = React.useMemo(() => {
    if (!custom) return;

    const { windowWidth } = Taro.getSystemInfoSync();
    const { bottom, right } = Taro.getMenuButtonBoundingClientRect();
    
    const gap = windowWidth - right;
    const navBarHeight = bottom + gap;

    return {
      paddingTop: `${navBarHeight}px`,
    }
  }, [custom]);

  const clsName = `page ${className}`;
  const sty = { ...style, ...innerStyle };

  return (
    <View className={clsName} style={sty}>
      {
        custom && <NavBar title={title} showHome={showHome} />
      }
      {props.children}
      <Tabbar active={active} activeColor="#07c160" onChange={onTabChange}>
        <TabbarItem>绑定设备</TabbarItem>
        <TabbarItem>
          我的
        </TabbarItem>
      </Tabbar>
    </View>
  )
}
