import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Icon } from '@antmjs/vantui';

import './style.less'

export default (props) => {
  const { title, showHome = false } = props;

  const [pgLen, setPgLen] = React.useState(0);
  const [style1, style2, style3, style4] = React.useMemo(() => {
    const { statusBarHeight, windowWidth } = Taro.getSystemInfoSync();
    const { bottom, right, width, height, left, top } = Taro.getMenuButtonBoundingClientRect();

    const gap = windowWidth - right;
    
    const wrapperStyle = {
      paddingTop: `${statusBarHeight}px`,
      height: `${bottom + gap}px`,
      width: `${left}px`,
    }

    const barStyle = {
      paddingTop: `${top - statusBarHeight}px`,
      paddingLeft: `${gap}px`,
      paddingRight: 0,
      height: `${height}px`,
      lineHeight: `${height}px`,
    }

    const navStyle = {
      width: `${width}px`
    }

    const titleStype = {
      padding: `0 ${gap}px`,
    }

    return [
      wrapperStyle,
      barStyle,
      navStyle,
      titleStype
    ]
  }, []);

  const isBack = pgLen > 1;

  const goHome = () => {
    Taro.reLaunch({ url: '/pages/index/index' });
  }

  const goBack = () => {
    Taro.navigateBack({
      delta: 1
    })
  }

  Taro.useDidShow(() => {
    const pages = Taro.getCurrentPages();
    setPgLen(pages ? pages.length : 0);
  })

  return (
    <View className="navbar-wrapper" style={style1}>
      <View className="navabar-container" style={style2}>
        <View style={style3}>
          {
            showHome && <View className="navabar-icon" onClick={goHome}><Icon name="wap-home-o" size={36} /></View>
          }
          {
            isBack && !showHome && <View className="navabar-icon" onClick={goBack}><Icon name="arrow-left" size={36} /></View>
          }
        </View>
        <View style={style4}>{title}</View>
      </View>
    </View>
  )
}
